@@ -17,8 +17,10 @@
  *  Boston, MA 02110-1301, USA.
  */
 
+
 #include "kservicetypeprofile.h"
 #include "kservicetypeprofile_p.h"
+
 #include "kservice.h"
 #include "kserviceoffer.h"
 #include "kservicetype.h"
@@ -28,7 +30,7 @@
 #include <kconfiggroup.h>
 
 #include <QMutex>
-#include <QtCore/QHash>
+#include <QHash>
 #include <QtAlgorithms>
 
 // servicetype -> profile
@@ -89,7 +91,7 @@ void KServiceTypeProfiles::ensureParsed()
         }
 
         for (int i = 0; i < count; ++i) {
-            const QString num = QString::fromLatin1("Entry") + QString::number(i);
+            const QString num = QLatin1String("Entry") + QString::number(i);
             const QString serviceId = config.readEntry(num + QLatin1String("_Service"), QString());
             if (!serviceId.isEmpty()) {
                 const int pref = config.readEntry(num + QLatin1String("_Preference"), 0);
@@ -140,7 +142,11 @@ KServiceOfferList KServiceTypeProfile::sortServiceTypeOffers(const KServiceOffer
                 const int pref = it2.value();
                 //qDebug() << "found in mapServices pref=" << pref;
                 if (pref > 0) {   // 0 disables the service
+#if KSERVICE_BUILD_DEPRECATED_SINCE(5, 69)
                     offers.append(KServiceOffer(servPtr, pref, 0, servPtr->allowAsDefault()));
+#else
+                    offers.append(KServiceOffer(servPtr, pref, 0));
+#endif
                 }
                 foundInProfile = true;
             }
@@ -155,12 +161,16 @@ KServiceOfferList KServiceTypeProfile::sortServiceTypeOffers(const KServiceOffer
             // If there's a profile, we use 0 as the preference to ensure new apps don't take over existing apps (which default to 1)
             offers.append(KServiceOffer(servPtr,
                                         profile ? 0 : (*it).preference(),
+#if KSERVICE_BUILD_DEPRECATED_SINCE(5, 69)
                                         0,
                                         servPtr->allowAsDefault()));
+#else
+                                        0));
+#endif
         }
     }
 
-    qStableSort(offers);
+    std::stable_sort(offers.begin(), offers.end());
 
     //qDebug() << "KServiceTypeProfile::offers returning " << offers.count() << " offers";
     return offers;
@@ -171,6 +181,7 @@ bool KServiceTypeProfile::hasProfile(const QString &serviceType)
     return s_serviceTypeProfiles()->hasProfile(serviceType);
 }
 
+#if KSERVICE_BUILD_DEPRECATED_SINCE(5, 66)
 void KServiceTypeProfile::writeServiceTypeProfile(const QString &serviceType,
         const KService::List &services,
         const KService::List &disabledServices)
@@ -196,7 +207,7 @@ void KServiceTypeProfile::writeServiceTypeProfile(const QString &serviceType,
     int i = 0;
     for (; servit != services.end(); ++servit, ++i) {
         if (*servit) {
-            const QString num = QString::fromLatin1("Entry") + QString::number(i);
+            const QString num = QLatin1String("Entry") + QString::number(i);
             config.writeEntry(num + QLatin1String("_Service"), (*servit)->storageId());
             config.writeEntry(num + QLatin1String("_Preference"), count - i);
         }
@@ -204,7 +215,7 @@ void KServiceTypeProfile::writeServiceTypeProfile(const QString &serviceType,
     servit = disabledServices.begin();
     for (; servit != disabledServices.end(); ++servit, ++i) {
         if (*servit) {
-            const QString num = QString::fromLatin1("Entry") + QString::number(i);
+            const QString num = QLatin1String("Entry") + QString::number(i);
             config.writeEntry(num + QLatin1String("_Service"), (*servit)->storageId());
             config.writeEntry(num + QLatin1String("_Preference"), 0);
         }
@@ -214,7 +225,9 @@ void KServiceTypeProfile::writeServiceTypeProfile(const QString &serviceType,
     // Drop the whole cache...
     clearCache();
 }
+#endif
 
+#if KSERVICE_BUILD_DEPRECATED_SINCE(5, 66)
 void KServiceTypeProfile::deleteServiceTypeProfile(const QString &serviceType)
 {
     KConfig config(QStringLiteral("servicetype_profilerc"), KConfig::SimpleConfig);
@@ -227,3 +240,4 @@ void KServiceTypeProfile::deleteServiceTypeProfile(const QString &serviceType)
         delete s_serviceTypeProfiles()->take(serviceType);
     }
 }
+#endif
