@@ -42,11 +42,13 @@ let users configure the application-mimetype associations.
 Example file:
 
 [Added Associations]
-text/plain=kate.desktop;
+text/plain=gnome-gedit.desktop;gnu-emacs.desktop;
 
 [Removed Associations]
 text/plain=gnome-gedit.desktop;gnu-emacs.desktop;
 
+[Default Applications]
+text/plain=kate.desktop;
 */
 
 void KMimeAssociations::parseAllMimeAppsList()
@@ -54,7 +56,12 @@ void KMimeAssociations::parseAllMimeAppsList()
     QStringList mimeappsFileNames;
     // make the list of possible filenames from the spec ($desktop-mimeapps.list, then mimeapps.list)
     const QString desktops = QString::fromLocal8Bit(qgetenv("XDG_CURRENT_DESKTOP"));
-    foreach (const QString &desktop, desktops.split(QLatin1Char(':'), QString::SkipEmptyParts)) {
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+    const auto list = desktops.split(QLatin1Char(':'), QString::SkipEmptyParts);
+#else
+    const auto list = desktops.split(QLatin1Char(':'), Qt::SkipEmptyParts);
+#endif
+    for (const QString &desktop : list) {
         mimeappsFileNames.append(desktop.toLower() + QLatin1String("-mimeapps.list"));
     }
     mimeappsFileNames.append(QStringLiteral("mimeapps.list"));
@@ -63,8 +70,8 @@ void KMimeAssociations::parseAllMimeAppsList()
                                     + QStandardPaths::standardLocations(QStandardPaths::ApplicationsLocation);
     QStringList mimeappsFiles;
     // collect existing files
-    foreach (const QString &dir, mimeappsDirs) {
-        foreach (const QString &file, mimeappsFileNames) {
+    for (const QString &dir : mimeappsDirs) {
+        for (const QString &file : qAsConst(mimeappsFileNames)) {
             const QString filePath = dir + QLatin1Char('/') + file;
             if (QFile::exists(filePath)) {
                 mimeappsFiles.append(filePath);
@@ -96,29 +103,36 @@ void KMimeAssociations::parseMimeAppsList(const QString &file, int basePreferenc
         parseRemovedAssociations(KConfigGroup(&profile, "Removed KDE Service Associations"), file);
     }
 
-    // TODO "Default Applications" is a separate query and a separate algorithm, says the spec.
-    // For now this is better than nothing though.
-    parseAddedAssociations(KConfigGroup(&profile, "Default Applications"), file, basePreference);
+    // Default Applications is preferred over Added Associations.
+    // Other than that, they work the same...
+    // add 25 to the basePreference to make sure those service offers will have higher preferences
+    // 25 is arbitrary half of the allocated preference indices for the current parsed mimeapps.list file, defined line 86
+    parseAddedAssociations(KConfigGroup(&profile, "Default Applications"), file, basePreference + 25);
 }
 
 void KMimeAssociations::parseAddedAssociations(const KConfigGroup &group, const QString &file, int basePreference)
 {
     Q_UNUSED(file) // except in debug statements
     QMimeDatabase db;
-    Q_FOREACH (const QString &mimeName, group.keyList()) {
+    const auto keyList = group.keyList();
+    for (const QString &mimeName : keyList) {
         const QStringList services = group.readXdgListEntry(mimeName);
         const QString resolvedMimeName = mimeName.startsWith(QLatin1String("x-scheme-handler/")) ? mimeName : db.mimeTypeForName(mimeName).name();
         if (resolvedMimeName.isEmpty()) {
             qCDebug(SYCOCA) << file << "specifies unknown mimeType" << mimeName << "in" << group.name();
         } else {
             int pref = basePreference;
-            Q_FOREACH (const QString &service, services) {
+            for (const QString &service : services) {
                 KService::Ptr pService = m_serviceFactory->findServiceByStorageId(service);
                 if (!pService) {
                     qCDebug(SYCOCA) << file << "specifies unknown service" << service << "in" << group.name();
                 } else {
                     //qDebug() << "adding mime" << resolvedMimeName << "to service" << pService->entryPath() << "pref=" << pref;
+#if KSERVICE_BUILD_DEPRECATED_SINCE(5, 69)
                     m_offerHash.addServiceOffer(resolvedMimeName, KServiceOffer(pService, pref, 0, pService->allowAsDefault()));
+#else
+                    m_offerHash.addServiceOffer(resolvedMimeName, KServiceOffer(pService, pref, 0));
+#endif
                     --pref;
                 }
             }
@@ -129,9 +143,10 @@ void KMimeAssociations::parseAddedAssociations(const KConfigGroup &group, const
 void KMimeAssociations::parseRemovedAssociations(const KConfigGroup &group, const QString &file)
 {
     Q_UNUSED(file) // except in debug statements
-    Q_FOREACH (const QString &mime, group.keyList()) {
+    const auto keyList = group.keyList();
+    for (const QString &mime : keyList) {
         const QStringList services = group.readXdgListEntry(mime);
-        Q_FOREACH (const QString &service, services) {
+        for (const QString &service : services) {
             KService::Ptr pService =  m_serviceFactory->findServiceByStorageId(service);
             if (!pService) {
                 //qDebug() << file << "specifies unknown service" << service << "in" << group.name();
